/*==============================================================*/
/* DBMS name:      MySQL 5.0                                    */
/* Created on:     02/12/2013 11:33:46                          */
/*==============================================================*/


drop table if exists actions;

drop table if exists allowed_actions;

drop table if exists authtokens;

drop table if exists carts;

drop table if exists cities;

drop table if exists customers;

drop table if exists invoices;

drop table if exists orders;

drop table if exists order_products;

drop table if exists parameters;

drop table if exists products;

drop table if exists profiles;

drop table if exists profile_actions;

drop table if exists providers;

drop table if exists provinces;

drop table if exists purchases;

drop table if exists purchase_products;

drop table if exists users;

/*==============================================================*/
/* Table: actions                                               */
/*==============================================================*/
create table actions
(
   id                   int(11) not null auto_increment,
   parent_id            int(11),
   name                 varchar(255) not null,
   link                 varchar(255),
   primary key (id)
);

/*==============================================================*/
/* Table: allowed_actions                                       */
/*==============================================================*/
create table allowed_actions
(
   id                   int(11) not null auto_increment,
   action_id            int(11) not null,
   url                  varchar(255) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: authtokens                                            */
/*==============================================================*/
create table authtokens
(
   id                   int(11) not null auto_increment,
   customer_id          int(11),
   token                varchar(22) not null,
   type                 varchar(25) not null,
   create_date          timestamp not null,
   expiration_date      timestamp not null,
   primary key (id)
);

/*==============================================================*/
/* Table: carts                                                 */
/*==============================================================*/
create table carts
(
   id                   int(11) not null auto_increment,
   customer_id          int(11) not null,
   product_id           int(11) not null,
   quantity             int not null,
   primary key (id)
);

/*==============================================================*/
/* Table: cities                                                */
/*==============================================================*/
create table cities
(
   id                   int(11) not null auto_increment,
   province_id          int(11) not null,
   name                 varchar(50) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: customers                                             */
/*==============================================================*/
create table customers
(
   id                   int(11) not null auto_increment,
   city_id              int(11) not null,
   ruc                  varchar(13) not null,
   name                 varchar(100) not null,
   last_name            varchar(100) not null,
   address              varchar(200) not null,
   reference            varchar(200),
   phone                varchar(15) not null,
   cellphone            varchar(12) not null,
   email                varchar(50) not null,
   status               enum('ACTIVE','INACTIVE','PENDING') not null,
   password             varchar(150) not null,
   zipcode              int not null,
   primary key (id)
);

/*==============================================================*/
/* Table: invoices                                              */
/*==============================================================*/
create table invoices
(
   id                   int(11) not null auto_increment,
   order_id             int(11) not null,
   address              varchar(200) not null,
   subtotal             decimal(6,2) not null,
   iva                  decimal(6,2) not null,
   total                decimal(6,2) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: orders                                                */
/*==============================================================*/
create table orders
(
   id                   int(11) not null auto_increment,
   invoice_id           int(11),
   customer_id          int(11) not null,
   status               enum('ORDERED','PAYED','SHIPPED','CANCELED') not null,
   date                 date not null,
   subtotal             decimal(6,2) not null,
   iva                  decimal(6,2) not null,
   total                decimal(6,2) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: order_products                                        */
/*==============================================================*/
create table order_products
(
   order_id             int(11) not null,
   product_id           int(11) not null,
   price                decimal(6,2),
   stock                int,
   primary key (order_id, product_id)
);

/*==============================================================*/
/* Table: parameters                                            */
/*==============================================================*/
create table parameters
(
   id                   int(11) not null auto_increment,
   description          varchar(100) not null,
   value                decimal(5,2) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: products                                              */
/*==============================================================*/
create table products
(
   id                   int(11) not null auto_increment,
   code                 varchar(100) not null,
   name                 varchar(150) not null,
   description          varchar(200) not null,
   buy_price            decimal(5,2) not null,
   sell_price           decimal(5,2) not null,
   image                varchar(200) not null,
   stock                int not null,
   type                 enum('BRAKEPAD','BAND') not null,
   primary key (id)
);

/*==============================================================*/
/* Table: profiles                                              */
/*==============================================================*/
create table profiles
(
   id                   int(11) not null auto_increment,
   name                 varchar(120) not null,
   status               enum('ACTIVE','INACTIVE') not null,
   primary key (id)
);

/*==============================================================*/
/* Table: profile_actions                                       */
/*==============================================================*/
create table profile_actions
(
   action_id            int(11) not null,
   profile_id           int(11) not null,
   primary key (action_id, profile_id)
);

/*==============================================================*/
/* Table: providers                                             */
/*==============================================================*/
create table providers
(
   id                   int(11) not null auto_increment,
   city_id              int(11) not null,
   ruc                  varchar(13) not null,
   name                 varchar(150) not null,
   address              varchar(200) not null,
   phone                varchar(15) not null,
   fax                  varchar(15),
   cellphone            varchar(12) not null,
   email                varchar(50),
   status               enum('ACTIVE','INACTIVE') not null,
   primary key (id)
);

/*==============================================================*/
/* Table: provinces                                             */
/*==============================================================*/
create table provinces
(
   id                   int(11) not null auto_increment,
   name                 varchar(50) not null,
   primary key (id)
);

/*==============================================================*/
/* Table: purchases                                             */
/*==============================================================*/
create table purchases
(
   id                   int(11) not null auto_increment,
   provider_id          int(11) not null,
   date                 date not null,
   number_invoice       varchar(20) not null,
   subtotal             decimal(6,2),
   total                decimal(6,2),
   iva                  decimal(6,2),
   primary key (id)
);

/*==============================================================*/
/* Table: purchase_products                                     */
/*==============================================================*/
create table purchase_products
(
   purchase_id          int(11) not null,
   product_id           int(11) not null,
   buy_price            decimal(5,2),
   stock                int,
   primary key (purchase_id, product_id)
);

/*==============================================================*/
/* Table: users                                                 */
/*==============================================================*/
create table users
(
   id                   int(11) not null auto_increment,
   profile_id           int(11) not null,
   username             varchar(150) not null,
   password             varchar(150) not null,
   name                 varchar(150) not null,
   last_name            varchar(150) not null,
   email                varchar(150) not null,
   status               enum('ACTIVE','INACTIVE') not null,
   primary key (id)
);

alter table actions add constraint fk_relationship_5 foreign key (parent_id)
      references actions (id) on delete restrict on update restrict;

alter table allowed_actions add constraint fk_relationship_1 foreign key (action_id)
      references actions (id) on delete restrict on update restrict;

alter table authtokens add constraint fk_relationship_12 foreign key (customer_id)
      references customers (id) on delete restrict on update restrict;

alter table carts add constraint fk_relationship_18 foreign key (product_id)
      references products (id) on delete restrict on update restrict;

alter table carts add constraint fk_relationship_19 foreign key (customer_id)
      references customers (id) on delete restrict on update restrict;

alter table cities add constraint fk_relationship_9 foreign key (province_id)
      references provinces (id) on delete restrict on update restrict;

alter table customers add constraint fk_relationship_11 foreign key (city_id)
      references cities (id) on delete restrict on update restrict;

alter table invoices add constraint fk_relationship_17 foreign key (order_id)
      references orders (id) on delete restrict on update restrict;

alter table orders add constraint fk_relationship_13 foreign key (customer_id)
      references customers (id) on delete restrict on update restrict;

alter table orders add constraint fk_relationship_16 foreign key (invoice_id)
      references invoices (id) on delete restrict on update restrict;

alter table order_products add constraint fk_relationship_14 foreign key (order_id)
      references products (id) on delete restrict on update restrict;

alter table order_products add constraint fk_relationship_15 foreign key (product_id)
      references orders (id) on delete restrict on update restrict;

alter table profile_actions add constraint fk_relationship_2 foreign key (action_id)
      references actions (id) on delete restrict on update restrict;

alter table profile_actions add constraint fk_relationship_3 foreign key (profile_id)
      references profiles (id) on delete restrict on update restrict;

alter table providers add constraint fk_relationship_10 foreign key (city_id)
      references cities (id) on delete restrict on update restrict;

alter table purchases add constraint fk_relationship_8 foreign key (provider_id)
      references providers (id) on delete restrict on update restrict;

alter table purchase_products add constraint fk_relationship_6 foreign key (purchase_id)
      references purchases (id) on delete restrict on update restrict;

alter table purchase_products add constraint fk_relationship_7 foreign key (product_id)
      references products (id) on delete restrict on update restrict;

alter table users add constraint fk_relationship_4 foreign key (profile_id)
      references profiles (id) on delete restrict on update restrict;

